@@ -1,4 +1,6 @@
 package Acme::Alien::DontPanic::Install::Files;
+use strict;
+use warnings;
 require Acme::Alien::DontPanic;
 sub Inline { shift; Acme::Alien::DontPanic->Inline(@_) }
 1;
